numpy.ma.masked_array
=====================

.. currentmodule:: numpy.ma

.. autoclass:: masked_array

   

   .. HACK
      .. autosummary::
         :toctree:
      
         masked_array.__init__
         masked_array.all
         masked_array.anom
         masked_array.any
         masked_array.argmax
         masked_array.argmin
         masked_array.argsort
         masked_array.astype
         masked_array.byteswap
         masked_array.choose
         masked_array.clip
         masked_array.compress
         masked_array.compressed
         masked_array.conj
         masked_array.conjugate
         masked_array.copy
         masked_array.count
         masked_array.cumprod
         masked_array.cumsum
         masked_array.diagonal
         masked_array.dot
         masked_array.dump
         masked_array.dumps
         masked_array.fill
         masked_array.filled
         masked_array.flatten
         masked_array.get_fill_value
         masked_array.get_imag
         masked_array.get_real
         masked_array.getfield
         masked_array.harden_mask
         masked_array.ids
         masked_array.iscontiguous
         masked_array.item
         masked_array.itemset
         masked_array.max
         masked_array.mean
         masked_array.min
         masked_array.mini
         masked_array.newbyteorder
         masked_array.nonzero
         masked_array.prod
         masked_array.product
         masked_array.ptp
         masked_array.put
         masked_array.ravel
         masked_array.repeat
         masked_array.reshape
         masked_array.resize
         masked_array.round
         masked_array.searchsorted
         masked_array.set_fill_value
         masked_array.setasflat
         masked_array.setfield
         masked_array.setflags
         masked_array.shrink_mask
         masked_array.soften_mask
         masked_array.sort
         masked_array.squeeze
         masked_array.std
         masked_array.sum
         masked_array.swapaxes
         masked_array.take
         masked_array.tofile
         masked_array.toflex
         masked_array.tolist
         masked_array.torecords
         masked_array.tostring
         masked_array.trace
         masked_array.transpose
         masked_array.unshare_mask
         masked_array.var
         masked_array.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         masked_array.T
         masked_array.base
         masked_array.baseclass
         masked_array.ctypes
         masked_array.data
         masked_array.dtype
         masked_array.fill_value
         masked_array.flags
         masked_array.flat
         masked_array.hardmask
         masked_array.imag
         masked_array.itemsize
         masked_array.mask
         masked_array.nbytes
         masked_array.ndim
         masked_array.real
         masked_array.recordmask
         masked_array.shape
         masked_array.sharedmask
         masked_array.size
         masked_array.strides

